# doc/README.md

A testfile should not be generated from this file.

```python
assert False, "Should not create a testfile from this file."
```

```py
>>> assert False, "Should not create a testfile from this file."
```
